#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
	module API
		module MappingServices
			class Mapping < MasterCard::Core::Model::BaseObject
				include MasterCard::Core::Model
				#

				@__store = {
					'6ab75199-b605-4051-a378-881454c85bad' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/{mappingId}/accounts/{accountId}/additional-data", "create", [], []),
					'60da0153-7a7b-4740-af37-6f2c6cbb6010' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/{mappingId}/accounts", "create", [], []),
					'cb3eb25a-78fc-4612-8052-8bbb368c46ce' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings", "create", [], []),
					'2bdd086c-2346-4731-89ca-94efe9cd7dd7' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/{mappingId}/accounts/{accountId}/additional-data/{additionalDataId}", "delete", [], []),
					'9319bd90-706b-483c-8deb-4601c346000f' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/{mappingId}", "delete", [], []),
					'8c94f9c5-0493-45f9-9b0c-87f5d48600b5' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/{mappingId}/accounts/{accountId}", "delete", [], []),
					'899b45f7-5d1e-4cd1-a57d-8a9141890412' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/{mappingId}/accounts", "query", [], []),
					'37f8c951-53fd-450f-9a84-95d19915cd79' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/{mappingId}/accounts/{accountId}/additional-data", "query", [], []),
					'1b95654b-f5fd-4f9d-a13a-b6eb40a17bec' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/{mappingId}/accounts/{accountId}/additional-data/{additionalDataId}", "read", [], []),
					'9fa07208-9a11-41df-98e5-c7fa82570ae9' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/{mappingId}/accounts/{accountId}", "read", [], []),
					'8f778e3a-4226-45fa-bf22-8598875564fe' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/{mappingId}", "read", [], []),
					'ea211a63-061d-47e5-afc7-838181721627' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings", "query", [], ["ref","customer_identifier"]),
					'd8294a30-f333-4fa5-bbf4-212f7cb9495d' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/search", "create", [], []),
					'2893bda0-0b05-4670-82de-716f698d612e' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/{mappingId}/accounts/{accountId}/additional-data/{additionalDataId}", "update", [], []),
					'b8b291ba-bbf1-4e44-88aa-bf3e22aaf82e' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/{mappingId}", "update", [], []),
					'7bb7b688-87a1-4f79-a12c-e90fa7396a0a' => OperationConfig.new("/send/v1/partners/{partnerId}/mappings/{mappingId}/accounts/{accountId}", "update", [], []),
					
				}

				protected

				def self.getOperationConfig(operationUUID)
					if @__store.key?(operationUUID)
						return @__store[operationUUID]
					end
					raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
				end

				def self.getOperationMetadata()
					return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
				end

				public


				def self.addAdditonalData(mapObj)
					#
					#Creates object of type Mapping
					#
					#@param Dict mapObj, containing the required parameters to create a new object
					#@return [Mapping] of the response of created instance.
					#@raise [APIException] an exception from the response status
					return self.execute("6ab75199-b605-4051-a378-881454c85bad", Mapping.new(mapObj))
				end







				def self.addMappingAccount(mapObj)
					#
					#Creates object of type Mapping
					#
					#@param Dict mapObj, containing the required parameters to create a new object
					#@return [Mapping] of the response of created instance.
					#@raise [APIException] an exception from the response status
					return self.execute("60da0153-7a7b-4740-af37-6f2c6cbb6010", Mapping.new(mapObj))
				end







				def self.createMapping(mapObj)
					#
					#Creates object of type Mapping
					#
					#@param Dict mapObj, containing the required parameters to create a new object
					#@return [Mapping] of the response of created instance.
					#@raise [APIException] an exception from the response status
					return self.execute("cb3eb25a-78fc-4612-8052-8bbb368c46ce", Mapping.new(mapObj))
				end










				def self.deleteAdditionalDataById(id, map = nil)
					#Delete object of type Mapping by id

					#@param [String] id
					#@param [Dict] map, containing additional parameters
					#@return [Mapping] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status


					mapObj = Mapping.new
					if !(id.nil? || id.to_s.empty?)
					  mapObj.set("id", id)
					end
					if !map.nil?
						if map.instance_of? RequestMap
						  mapObj.setAll(map.getObject())
						else
						  mapObj.setAll(map)
						end
					end

					return self.execute("2bdd086c-2346-4731-89ca-94efe9cd7dd7", mapObj)
				end


				def deleteAdditionalData
					#
					#Delete object of type Mapping

					#@param [String] id
					#@return [Mapping] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status
					#

					return self.class.execute("2bdd086c-2346-4731-89ca-94efe9cd7dd7", self)
				end







				def self.deleteMappingById(id, map = nil)
					#Delete object of type Mapping by id

					#@param [String] id
					#@param [Dict] map, containing additional parameters
					#@return [Mapping] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status


					mapObj = Mapping.new
					if !(id.nil? || id.to_s.empty?)
					  mapObj.set("id", id)
					end
					if !map.nil?
						if map.instance_of? RequestMap
						  mapObj.setAll(map.getObject())
						else
						  mapObj.setAll(map)
						end
					end

					return self.execute("9319bd90-706b-483c-8deb-4601c346000f", mapObj)
				end


				def deleteMapping
					#
					#Delete object of type Mapping

					#@param [String] id
					#@return [Mapping] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status
					#

					return self.class.execute("9319bd90-706b-483c-8deb-4601c346000f", self)
				end







				def self.deleteMappingAccountById(id, map = nil)
					#Delete object of type Mapping by id

					#@param [String] id
					#@param [Dict] map, containing additional parameters
					#@return [Mapping] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status


					mapObj = Mapping.new
					if !(id.nil? || id.to_s.empty?)
					  mapObj.set("id", id)
					end
					if !map.nil?
						if map.instance_of? RequestMap
						  mapObj.setAll(map.getObject())
						else
						  mapObj.setAll(map)
						end
					end

					return self.execute("8c94f9c5-0493-45f9-9b0c-87f5d48600b5", mapObj)
				end


				def deleteMappingAccount
					#
					#Delete object of type Mapping

					#@param [String] id
					#@return [Mapping] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status
					#

					return self.class.execute("8c94f9c5-0493-45f9-9b0c-87f5d48600b5", self)
				end









				def self.listAllAccounts(criteria)
					#
					#Query objects of type Mapping by id and optional criteria
					#@param [Dict] criteria
					#@return [Mapping] object representing the response.
					#@raise [APIException] an exception from the response status
					#

					return self.execute("899b45f7-5d1e-4cd1-a57d-8a9141890412",Mapping.new(criteria))
				end







				def self.listAllAdditionalData(criteria)
					#
					#Query objects of type Mapping by id and optional criteria
					#@param [Dict] criteria
					#@return [Mapping] object representing the response.
					#@raise [APIException] an exception from the response status
					#

					return self.execute("37f8c951-53fd-450f-9a84-95d19915cd79",Mapping.new(criteria))
				end






				def self.readByAdditionalDataId(id, criteria = nil)
					#
					#Returns objects of type Mapping by id and optional criteria
					#@param [String] id
					#@param [Dict] criteria
					#@return [Mapping] object representing the response
					#@raise [APIException] an exception from the response status

					mapObj = Mapping.new
					if !(id.nil? || id.to_s.empty?)
					  mapObj.set("id", id)
					end
					if !criteria.nil?
						if criteria.instance_of? RequestMap
						  mapObj.setAll(criteria.getObject())
						else
						  mapObj.setAll(criteria)
						end
					end

					return self.execute("1b95654b-f5fd-4f9d-a13a-b6eb40a17bec",Mapping.new(mapObj))
				end







				def self.readByMappingAccountId(id, criteria = nil)
					#
					#Returns objects of type Mapping by id and optional criteria
					#@param [String] id
					#@param [Dict] criteria
					#@return [Mapping] object representing the response
					#@raise [APIException] an exception from the response status

					mapObj = Mapping.new
					if !(id.nil? || id.to_s.empty?)
					  mapObj.set("id", id)
					end
					if !criteria.nil?
						if criteria.instance_of? RequestMap
						  mapObj.setAll(criteria.getObject())
						else
						  mapObj.setAll(criteria)
						end
					end

					return self.execute("9fa07208-9a11-41df-98e5-c7fa82570ae9",Mapping.new(mapObj))
				end







				def self.readByMappingId(id, criteria = nil)
					#
					#Returns objects of type Mapping by id and optional criteria
					#@param [String] id
					#@param [Dict] criteria
					#@return [Mapping] object representing the response
					#@raise [APIException] an exception from the response status

					mapObj = Mapping.new
					if !(id.nil? || id.to_s.empty?)
					  mapObj.set("id", id)
					end
					if !criteria.nil?
						if criteria.instance_of? RequestMap
						  mapObj.setAll(criteria.getObject())
						else
						  mapObj.setAll(criteria)
						end
					end

					return self.execute("8f778e3a-4226-45fa-bf22-8598875564fe",Mapping.new(mapObj))
				end








				def self.listByReferenceOrCustomerIdentifier(criteria)
					#
					#Query objects of type Mapping by id and optional criteria
					#@param [Dict] criteria
					#@return [Mapping] object representing the response.
					#@raise [APIException] an exception from the response status
					#

					return self.execute("ea211a63-061d-47e5-afc7-838181721627",Mapping.new(criteria))
				end


				def self.searchMapping(mapObj)
					#
					#Creates object of type Mapping
					#
					#@param Dict mapObj, containing the required parameters to create a new object
					#@return [Mapping] of the response of created instance.
					#@raise [APIException] an exception from the response status
					return self.execute("d8294a30-f333-4fa5-bbf4-212f7cb9495d", Mapping.new(mapObj))
				end








				def updateAdditonalData
					#
					#Updates an object of type Mapping
					#
					#@return [Mapping] object representing the response.
					#@raise [APIException] an exception from the response status
					#
					return self.class.execute("2893bda0-0b05-4670-82de-716f698d612e",self)
				end








				def updateMapping
					#
					#Updates an object of type Mapping
					#
					#@return [Mapping] object representing the response.
					#@raise [APIException] an exception from the response status
					#
					return self.class.execute("b8b291ba-bbf1-4e44-88aa-bf3e22aaf82e",self)
				end








				def updateMappingAccount
					#
					#Updates an object of type Mapping
					#
					#@return [Mapping] object representing the response.
					#@raise [APIException] an exception from the response status
					#
					return self.class.execute("7bb7b688-87a1-4f79-a12c-e90fa7396a0a",self)
				end







			end
		end
	end
end







